#!/usr/bin/env python
# -*- coding: utf-8 -*-

keys = {
	'consumer_key': '',
	'consumer_secret': '',
	'access_token': '',
	'access_secret': ''
}

settings = {
	'reversed_timeline': False,
	'reversed_mentions': False,
	'reversed_stalk': False,
	'WOEID': 1,
	'archive_path': '/path/',
	'reversed_archive' : False,
	'timezone': 'Europe/Paris'
}